@@ -1,6 +1,8 @@
 #
 # Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
 #
+# SPDX-License-Identifier: GPL-3.0-or-later
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -19,27 +21,16 @@ import argparse
 import logging
 import pickle
 import sys
-import textwrap
 from distutils.util import strtobool
 from signal import SIGINT, signal
 from timeit import default_timer as timer
 
-from plafosim import __version__
+from plafosim import CustomFormatter, __citation__, __description__, __version__
 from plafosim.algorithms.speed_position import SpeedPosition
 from plafosim.simulator import DEFAULTS, Simulator
 from plafosim.util import find_resource
 
 
-class CustomFormatter(
-    argparse.ArgumentDefaultsHelpFormatter,
-    argparse.RawDescriptionHelpFormatter,
-    argparse.MetavarTypeHelpFormatter,
-):
-    """Metaclass combining multiple formatter classes for argparse"""
-
-    pass
-
-
 # TODO duplicated code with trace replay
 def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
 
@@ -47,21 +38,7 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
     parser = argparse.ArgumentParser(
         formatter_class=CustomFormatter,
         allow_abbrev=False,
-        description=textwrap.dedent(f"""\
-            Platoon Formation Simulator (PlaFoSim) -- Version {__version__}.
-            A simple and scalable simulator for platoon formation.
-
-            Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
-            This program comes with ABSOLUTELY NO WARRANTY.
-            This is free software, and you are welcome to redistribute it under certain conditions.
-
-            If you are working with PlaFoSim, please cite the following paper:
-
-            Julian Heinovski, Dominik S. Buse and Falko Dressler,
-            "Scalable Simulation of Platoon Formation Maneuvers with PlaFoSim,"
-            Proceedings of 13th IEEE Vehicular Networking Conference (VNC 2021),
-            Poster Session, Virtual Conference, November 2021.
-        """),
+        description=__description__,
     )
 
     # miscellaneous
@@ -69,19 +46,7 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
         "-C", "--citation",
         action="version",
         help="show the citation information and exit",
-        version=textwrap.dedent("""
-            @inproceedings{heinovski2021scalable,
-                author = {Heinovski, Julian and Buse, Dominik S. and Dressler, Falko},
-                title = {{Scalable Simulation of Platoon Formation Maneuvers with PlaFoSim}},
-                publisher = {IEEE},
-                issn = {2157-9865},
-                isbn = {978-1-66544-450-7},
-                address = {Virtual Conference},
-                booktitle = {13th IEEE Vehicular Networking Conference (VNC 2021), Poster Session},
-                month = {11},
-                year = {2021},
-            }
-        """),
+        version=__citation__,
     )
     parser.add_argument(
         "-V", "--version",
@@ -98,6 +63,18 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
         action="store_true",
         help="show the current configuration and exit",
     )
+    parser.add_argument(
+        "-q", "--quiet",
+        action="count",
+        default=0,
+        help=f"The amount of verbosity levels to be removed for printing the logs to the CLI. The starting level is {logging.getLevelName(DEFAULTS['log_level'])}.",
+    )
+    parser.add_argument(
+        "-v", "--verbosity",
+        action="count",
+        default=0,
+        help=f"The amount of verbosity levels to be added for printing the logs to the CLI. The starting level is {logging.getLevelName(DEFAULTS['log_level'])}.",
+    )
     parser.add_argument(
         "--save-snapshot",
         type=str,
@@ -415,13 +392,6 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
         default=DEFAULTS['random_seed'],
         help="The seed (>=0) for the random number generator instead of the current system time",
     )
-    simulation.add_argument(
-        "--log-level",
-        type=str,
-        default=logging.getLevelName(DEFAULTS['log_level']).lower(),
-        choices=["error", "warn", "info", "debug", "trace"],
-        help="The minimum level of logs to be printed",
-    )
     simulation.add_argument(
         "--progress",
         type=lambda x: bool(strtobool(x)),
@@ -670,7 +640,7 @@ def create_simulator(**kwargs: dict) -> Simulator:
     # prepare keyword arguments for simulator
     kwargs.pop('load_snapshot')
     kwargs.pop('save_snapshot')
-    kwargs['log_level'] = getattr(logging, kwargs['log_level'].upper(), 5)
+    kwargs['log_level'] = logging.getLevelName(max(DEFAULTS['log_level'] - ((kwargs['verbosity'] - kwargs['quiet']) * 10), 5))
     kwargs['max_step'] = int(kwargs['max_step'])
 
     # create new simulator
@@ -716,7 +686,7 @@ def main():
         return
 
     def handler(signal, frame):
-        simulator.stop("SIGINT or CTRL-C detected!")
+        simulator.stop("SIGINT or CTRL-C detected! Stopping simulation...")
 
     signal(SIGINT, handler)
 
