@@ -1,6 +1,8 @@
 #
 # Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
 #
+# SPDX-License-Identifier: GPL-3.0-or-later
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -39,13 +41,17 @@ class EmissionClass(Enum):
 
     @property
     def emission_factors(self) -> dict:
-        """Returns the emission factors of an emission class."""
+        """
+        Return the emission factors of an emission class.
+        """
 
         return EMISSION_FACTORS[self.name]
 
     @property
     def is_diesel(self) -> bool:
-        """Returns whether an emission class is for a diesel engine."""
+        """
+        Return whether an emission class is for a diesel engine.
+        """
 
         split = self.name.split('_')
         assert len(split) == 3
