@@ -1,6 +1,8 @@
 #
 # Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
 #
+# SPDX-License-Identifier: GPL-3.0-or-later
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -18,7 +20,7 @@
 import logging
 import sys
 
-from .algorithms.speed_position import SpeedPosition
+from .algorithms.speed_position import SpeedPosition  # noqa 401
 from .platooning_vehicle import PlatooningVehicle
 
 #from .simulator import Simulator  # TODO fix circular import
@@ -58,11 +60,10 @@ class Infrastructure:
 
         if formation_algorithm is not None:
             # initialize formation algorithm
-            # TODO make enum
-            if formation_algorithm == SpeedPosition.__name__:
-                self._formation_algorithm = SpeedPosition(self, **kw_args)
-            else:
-                sys.exit(f"ERROR: Unknown formation algorithm {formation_algorithm}!")
+            try:
+                self._formation_algorithm = globals()[formation_algorithm](self, **kw_args)
+            except KeyError:
+                sys.exit(f"ERROR: Unknown formation algorithm {formation_algorithm}! Did you import it?")
             self._execution_interval = execution_interval
 
             # initialize timer
@@ -72,19 +73,23 @@ class Infrastructure:
 
     @property
     def iid(self) -> int:
-        """Returns the id of an infrastructure."""
+        """
+        Return the id of an infrastructure.
+        """
 
         return self._iid
 
     @property
     def position(self) -> int:
-        """Returns the position of an infrastructure."""
+        """
+        Return the position of an infrastructure.
+        """
 
         return self._position
 
     def action(self, step: int):
         """
-        Triggers actions of an infrastructure
+        Triggers actions of an infrastructure.
 
         Parameters
         ----------
@@ -133,7 +138,9 @@ class Infrastructure:
         return neighbors
 
     def finish(self):
-        """Cleans up the instance of the infrastructure"""
+        """
+        Clean up the instance of the infrastructure.
+        """
 
         if self._formation_algorithm is not None:
             self._formation_algorithm.finish()
