@@ -1,6 +1,8 @@
 #
 # Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
 #
+# SPDX-License-Identifier: GPL-3.0-or-later
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -19,7 +21,9 @@ from enum import Enum
 
 
 class PlatoonRole(Enum):
-    """A collection of available platoon roles."""
+    """
+    A collection of available platoon roles.
+    """
 
     NONE = 0  # corresponds to driving individually
     LEADER = 1  # corresponds to being the leader of a platoon
