@@ -1,6 +1,8 @@
 #
 # Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
 #
+# SPDX-License-Identifier: GPL-3.0-or-later
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +22,7 @@ import math
 import sys
 from typing import TYPE_CHECKING
 
-from .algorithms.speed_position import SpeedPosition
+from .algorithms.speed_position import SpeedPosition  # noqa 401
 from .gui import change_gui_vehicle_color
 from .message import Message, PlatoonAdvertisement
 from .mobility import CF_Model
@@ -44,7 +46,9 @@ LOG = logging.getLogger(__name__)
 
 
 class PlatooningVehicle(Vehicle):
-    """A vehicle that has platooning functionality."""
+    """
+    A vehicle that has platooning functionality.
+    """
 
     def __init__(
             self,
@@ -68,7 +72,7 @@ class PlatooningVehicle(Vehicle):
     ):
         # TODO use global default values
         """
-        Initializes a platooning vehicle instance.
+        Initialize a platooning vehicle instance.
 
         Parameters
         ----------
@@ -138,11 +142,10 @@ class PlatooningVehicle(Vehicle):
 
         if formation_algorithm:
             # initialize formation algorithm
-            # TODO make enum
-            if formation_algorithm == SpeedPosition.__name__:
-                self._formation_algorithm = SpeedPosition(self, **kw_args)
-            else:
-                sys.exit(f"ERROR: Unknown formation algorithm {formation_algorithm}!")
+            try:
+                self._formation_algorithm = globals()[formation_algorithm](self, **kw_args)
+            except KeyError:
+                sys.exit(f"ERROR: Unknown formation algorithm {formation_algorithm}! Did you import it?")
             self._execution_interval = execution_interval
 
             # initialize timers
@@ -206,14 +209,16 @@ class PlatooningVehicle(Vehicle):
 
     @property
     def acc_headway_time(self) -> float:
-        """Returns the ACC headway time of the vehicle."""
+        """
+        Return the ACC headway time of the vehicle.
+        """
 
         return self._acc_headway_time
 
     @property
     def desired_headway_time(self) -> float:
         """
-        Returns the desired headway time of the vehicle.
+        Return the desired headway time of the vehicle.
 
         This is based on the currently active car following model.
         """
@@ -227,7 +232,7 @@ class PlatooningVehicle(Vehicle):
     @property
     def desired_speed(self) -> float:
         """
-        Returns the desired driving speed of the vehicle.
+        Return the desired driving speed of the vehicle.
 
         If the vehicle is in a platoon, it returns the desired driving speed of the entire platoon.
         """
@@ -237,7 +242,7 @@ class PlatooningVehicle(Vehicle):
     @property
     def desired_gap(self) -> float:
         """
-        Returns the desired gap of the vehicle.
+        Return the desired gap of the vehicle.
 
         This is based on the currently active car following model.
         """
@@ -247,19 +252,23 @@ class PlatooningVehicle(Vehicle):
 
     @property
     def platoon_role(self) -> PlatoonRole:
-        """Returns the current platoon role of the vehicle."""
+        """
+        Return the current platoon role of the vehicle.
+        """
 
         return self._platoon_role
 
     @property
     def platoon(self) -> Platoon:
-        """Returns the platoon of the vehicle."""
+        """
+        Return the platoon of the vehicle.
+        """
 
         return self._platoon
 
     def is_in_platoon(self) -> bool:
         """
-        Returns whether the vehicle currently is in a platoon.
+        Return whether the vehicle currently is in a platoon.
 
         This is based on the current PlatoonRole.
         A joining or leaving vehicle is either not yet or still part of a platoon, thus the returned value should be true.
@@ -269,7 +278,7 @@ class PlatooningVehicle(Vehicle):
 
     def get_front_gap(self) -> float:
         """
-        Returns the gap to the vehicle in the front.
+        Return the gap to the vehicle in the front.
 
         This imitates a measurement of the front radar sensor.
         """
@@ -278,7 +287,7 @@ class PlatooningVehicle(Vehicle):
 
     def get_front_speed(self) -> float:
         """
-        Returns the speed to the vehicle in the front.
+        Return the speed to the vehicle in the front.
 
         This imitates a measurement of the front radar sensor.
         """
@@ -287,14 +296,16 @@ class PlatooningVehicle(Vehicle):
 
     @property
     def in_maneuver(self) -> bool:
-        """Returns whether the vehicle is currently in a maneuver."""
+        """
+        Return whether the vehicle is currently in a maneuver.
+        """
 
         return self._in_maneuver
 
     @in_maneuver.setter
     def in_maneuver(self, var: bool):
         """
-        Sets the maneuver status of the vehicle.
+        Set the maneuver status of the vehicle.
 
         Parameters
         ----------
@@ -307,13 +318,17 @@ class PlatooningVehicle(Vehicle):
 
     @property
     def time_in_platoon(self) -> int:
-        """Returns the travelled time within platoons."""
+        """
+        Return the travelled time within platoons.
+        """
 
         return self._time_in_platoon
 
     @property
     def distance_in_platoon(self) -> float:
-        """Returns the travelled distance within platoons."""
+        """
+        Return the travelled distance within platoons.
+        """
 
         return self._distance_in_platoon
 
@@ -325,7 +340,7 @@ class PlatooningVehicle(Vehicle):
 
     def _calculate_emission(self, a: float, v: float, f: list, scale: float) -> float:
         """
-        Calculates the emitted pollutant amount using the given speed and acceleration.
+        Calculate the emitted pollutant amount using the given speed and acceleration.
 
         Parameters
         ----------
@@ -371,7 +386,7 @@ class PlatooningVehicle(Vehicle):
 
     def finish(self):
         """
-        Cleans up the instance of the PlatooningVehicle.
+        Clean up the instance of the PlatooningVehicle.
 
         This includes leaving the platoon and mostly statistics recording.
         """
@@ -488,12 +503,16 @@ class PlatooningVehicle(Vehicle):
                 self._last_formation_step = step
 
     def info(self) -> str:
-        """Returns information about the PlatooningVehicle."""
+        """
+        Return information about the PlatooningVehicle.
+        """
 
         return f"{super().info()}, platoon {self._platoon}"
 
     def __str__(self) -> str:
-        """Returns the str representation of the platooning vehicle."""
+        """
+        Return the str representation of the platooning vehicle.
+        """
 
         self_dict = self.__dict__.copy()
         self_dict.update({'_vehicle_type': str(self._vehicle_type)})  # use str representation of vehicle type
@@ -501,7 +520,9 @@ class PlatooningVehicle(Vehicle):
         return str(self_dict)
 
     def _statistics(self):
-        """Writes continuous statistics."""
+        """
+        Write continuous statistics.
+        """
 
         super()._statistics()
 
@@ -528,7 +549,7 @@ class PlatooningVehicle(Vehicle):
     # TODO rework to only include "neighbors" and move platoon extraction to formation algorithm
     def _get_available_platoons(self):
         """
-        Returns the available platoon candidates of the vehicle.
+        Return the available platoon candidates of the vehicle.
 
         This imitates neighbor maintenance by using a neighbor table.
         """
@@ -956,7 +977,7 @@ class PlatooningVehicle(Vehicle):
 
     def calculate_approaching_time(self, target_position: float, target_speed: float) -> float:
         """
-        Calculate approximate time to approach the target position at target speed
+        Calculate approximate time to approach the target position at target speed.
 
         Parameters
         ----------
@@ -1147,6 +1168,8 @@ class PlatooningVehicle(Vehicle):
                 # TODO this looks strange in the GUI, since we do this before actually leaving the formation
                 self._platoon_role = PlatoonRole.LEAVER
                 self._cf_model = CF_Model.ACC
+                # FIXME Missing method. TODO Implement with new function!
+                sys.exit(f"ERROR: This is not implemented (anymore)! {__file__}:{sys._getframe().f_lineno}")
                 if not self._simulator._change_lane(self, self._lane + 1, "maneuver"):
                     # could not leave the platoon
                     # TODO this could be just a return in future to let the leaver try again
@@ -1251,7 +1274,7 @@ class PlatooningVehicle(Vehicle):
 
     def _handle_message(self, message: Message):
         """
-        Handles a message of arbitrary type Message.
+        Handle a message of arbitrary type Message.
 
         Messages are in general not used at the moment.
 
@@ -1270,7 +1293,7 @@ class PlatooningVehicle(Vehicle):
 
     def _receive_PlatoonAdvertisement(self, advertisement: PlatoonAdvertisement):
         """
-        Handles a message of the specific type PlatoonAdvertisement.
+        Handle a message of the specific type PlatoonAdvertisement.
 
         Messages are in general not used at the moment.
 
