@@ -1,6 +1,8 @@
 #
 # Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
 #
+# SPDX-License-Identifier: GPL-3.0-or-later
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -26,7 +28,9 @@ def get_desired_speed(
     max_desired_speed: float,
     random_desired_speed: bool = False,
 ) -> float:
-    """Returns a (random) depart speed."""
+    """
+    Return a (random) depart speed.
+    """
 
     if random_desired_speed:
         # normal distribution
@@ -46,7 +50,7 @@ def get_depart_speed(
     random_depart_speed: bool = False,
 ) -> float:
     """
-    Returns a (random) depart speed.
+    Return a (random) depart speed.
 
     Parameters
     ----------
@@ -77,7 +81,7 @@ def get_arrival_position(
     pre_fill: bool = False,
 ) -> int:
     """
-    Returns a (random) arrival position for a given depart position.
+    Return a (random) arrival position for a given depart position.
 
     This considers the ramp interval, road length, and minimum trip length.
 
@@ -123,10 +127,11 @@ def get_arrival_position(
     if min_arrival % ramp_interval == 0:
         assert min_arrival == min_arrival_ramp
 
-    if random_arrival_position and max_arrival_ramp < road_length:
+    if random_arrival_position:
         # make sure to also include the end of the road itself
         arrival_position = rng.randrange(min_arrival_ramp, max_arrival_ramp + 1, ramp_interval)
-        assert arrival_position >= min_arrival_ramp
+        assert min_arrival_ramp <= arrival_position <= max_arrival_ramp
+        assert arrival_position <= road_length
     else:
         # simply drive until the end of the trip or the road
         arrival_position = min(max_arrival_ramp, road_length)
